@@ -13,12 +13,17 @@ class Synapse(ABC):
     connection = None
     request = None
     request_type = None
+    init_error = None
 
     def __init__(self, raw_request: Request) -> None:
-        self.raw_request = Request.parse_raw(raw_request)
-        self.request_type = self.raw_request.type
-        self.connection = self.raw_request.connection
-        self.request = self.__set_request()
+        try:
+            self.raw_request = Request.parse_raw(raw_request)
+            self.request_type = self.raw_request.type
+            self.connection = self.raw_request.connection
+            self.request = self.__set_request()
+        except Exception as e:
+            err_msg = 'Failed to execute request {}'.format(raw_request)
+            self.init_error = ErrorResponse(message=err_msg, status_code=400, detail=str(e))
 
     def __set_request(self):
         if self.request_type == RequestType.DESCRIBE:
@@ -35,12 +40,16 @@ class Synapse(ABC):
             The route method that looks for the type of the synapse request and invokes
             appropriate synapse supported method.
         """
+        # If there is an initialization exception, just return as response. This is needed to capture it as a well defined error.
+        if self.init_error is not None:
+            return self.init_error
+
         self.logger.info(self.request_type)
         self.logger.info(self.request)
         response = None
         try:
             if self.request_type == RequestType.TEST:
-                response = self.test()
+                response = self.test(self.connection)
                 if not isinstance(response, Connection):
                     raise self.__prep_invalid_response_exception(response)
 
@@ -50,7 +59,7 @@ class Synapse(ABC):
                     raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.DESCRIBE:
-                response = self.describe()
+                response = self.describe(self.request)
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -58,12 +67,12 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.READ:
-                response = self.read()
+                response = self.read(self.request)
                 if not isinstance(response, ReadResponse):
                     raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.GET_BY_ID:
-                response = self.get_by_id()
+                response = self.get_by_id(self.request)
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -71,7 +80,7 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.CREATE:
-                response = self.create()
+                response = self.create(self.request)
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -79,7 +88,7 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.UPDATE:
-                response = self.update()
+                response = self.update(self.request)
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -87,7 +96,7 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.DELETE:
-                response = self.delete()
+                response = self.delete(self.request)
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -95,12 +104,12 @@ class Synapse(ABC):
                         raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.EXTRACT_WEBHOOK_IDENTIFIER:
-                response = self.extract_webhook_identifier()
+                response = self.extract_webhook_identifier(self.request)
                 if not isinstance(response, str):
                     raise self.__prep_invalid_response_exception(response)
 
             elif self.request_type == RequestType.PROCESS_WEBHOOK:
-                response = self.process_webhook()
+                response = self.process_webhook(self.request)
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -158,37 +167,37 @@ class Synapse(ABC):
         pass
 
     @abstractmethod
-    def test(self):
+    def test(self, connection: Connection):
         pass
 
     @abstractmethod
-    def describe(self):
+    def describe(self, desc_request: DescribeRequest):
         pass
 
     @abstractmethod
-    def read(self):
+    def read(self, sync_request: SyncRequest):
         pass
 
     @abstractmethod
-    def get_by_id(self):
+    def get_by_id(self, sync_request: SyncRequest):
         pass
 
     @abstractmethod
-    def create(self):
+    def create(self, sync_request: SyncRequest):
         pass
 
     @abstractmethod
-    def update(self):
+    def update(self, sync_request: SyncRequest):
         pass
 
     @abstractmethod
-    def delete(self):
+    def delete(self, sync_request: SyncRequest):
         pass
 
     @abstractmethod
-    def extract_webhook_identifier(self):
+    def extract_webhook_identifier(self, webhook_request: WebhookRequest):
         pass
 
     @abstractmethod
-    def process_webhook(self):
+    def process_webhook(self, webhook_request: WebhookRequest):
         pass
